@@ -8,7 +8,7 @@ import requests
 from requests.models import Response
 
 from . import consts
-from .common import trace_http_request, trace_http_response
+from .common import trace_http_request, trace_http_response, trace_http_response_raw
 
 
 class Session(requests.Session):
@@ -25,6 +25,7 @@ class Session(requests.Session):
         jdata = kwargs.get("json")
         trace_http_request("post", url, jdata)
         resp = super().post(url, **kwargs)
+        trace_http_response_raw(resp)
         return resp
 
     def json(self, resp):
